@@ -14,6 +14,8 @@ class Platformer(gym.Env):
     metadata = {'render.modes': ['human']}
 
     def __init__(self):
+        self.action_space = spaces.Discrete(8)
+        self.observation_space = spaces.Box(low=np.zeros(11)+float("-inf"), high=np.zeros(11)+float("inf"))
         platformer.create()
 
 
